km3pipe.io.CLBPump
==================

.. currentmodule:: km3pipe.io

.. autoclass:: CLBPump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CLBPump.__init__
      ~CLBPump.add
      ~CLBPump.close
      ~CLBPump.close_file
      ~CLBPump.configure
      ~CLBPump.determine_packet_positions
      ~CLBPump.expose
      ~CLBPump.finish
      ~CLBPump.get
      ~CLBPump.get_blob
      ~CLBPump.next
      ~CLBPump.next_blob
      ~CLBPump.open_file
      ~CLBPump.pre_finish
      ~CLBPump.process
      ~CLBPump.require
      ~CLBPump.rewind_file
      ~CLBPump.seek_to_packet
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CLBPump.name
   
   